@@ -4,7 +4,7 @@
 /* Simple test to ensure that we can load the xapian module and exercise basic
  * functionality successfully.
  *
- * Copyright (C) 2004-2022 Olly Betts
+ * Copyright (C) 2004-2026 Olly Betts
  * Copyright (C) 2010 Richard Boulton
  *
  * This program is free software; you can redistribute it and/or
@@ -72,18 +72,6 @@ try {
     }
 }
 
-# Check that open_stub() is wrapped as expected.
-try {
-    $db = Xapian::auto_open_stub("nosuchdir/nosuchdb");
-    print "Opened non-existent stub database\n";
-    exit(1);
-} catch (Exception $e) {
-    if ($e->getMessage() !== "DatabaseNotFoundError: Couldn't open stub database file: nosuchdir/nosuchdb (No such file or directory)") {
-	print "DatabaseOpeningError Exception string not as expected, got: '{$e->getMessage()}'\n";
-	exit(1);
-    }
-}
-
 # Check that DB_BACKEND_STUB works as expected.
 try {
     $db = new XapianDatabase("nosuchdir/nosuchdb", Xapian::DB_BACKEND_STUB);
@@ -96,18 +84,6 @@ try {
     }
 }
 
-# Check that open_stub() writable form is wrapped as expected.
-try {
-    $db = Xapian::auto_open_stub("nosuchdir/nosuchdb", Xapian::DB_OPEN);
-    print "Opened non-existent stub database\n";
-    exit(1);
-} catch (Exception $e) {
-    if ($e->getMessage() !== "DatabaseNotFoundError: Couldn't open stub database file: nosuchdir/nosuchdb (No such file or directory)") {
-	print "DatabaseOpeningError Exception string not as expected, got: '{$e->getMessage()}'\n";
-	exit(1);
-    }
-}
-
 # Check that DB_BACKEND_STUB works as expected.
 try {
     $db = new XapianWritableDatabase("nosuchdir/nosuchdb",
@@ -121,20 +97,6 @@ try {
     }
 }
 
-# Regression test for bug#193, fixed in 1.0.3.
-$vrp = new XapianNumberValueRangeProcessor(0, '$', true);
-$a = '$10';
-$b = '20';
-$vrp->apply($a, $b);
-if (Xapian::sortable_unserialise($a) != 10) {
-    print Xapian::sortable_unserialise($a)." != 10\n";
-    exit(1);
-}
-if (Xapian::sortable_unserialise($b) != 20) {
-    print Xapian::sortable_unserialise($b)." != 20\n";
-    exit(1);
-}
-
 $stem = new XapianStem("english");
 if ($stem->get_description() != "Xapian::Stem(english)") {
     print "Unexpected \$stem->get_description()\n";
@@ -255,7 +217,7 @@ class testexpanddecider extends XapianExpandDecider {
 $enquire = new XapianEnquire($db);
 $rset = new XapianRSet();
 $rset->add_document(1);
-$eset = $enquire->get_eset(10, $rset, XapianEnquire::USE_EXACT_TERMFREQ, 1.0, new testexpanddecider());
+$eset = $enquire->get_eset(10, $rset, XapianEnquire::USE_EXACT_TERMFREQ, new testexpanddecider());
 foreach ($eset->begin() as $t) {
     if ($t[0] === 'a') {
 	print "XapianExpandDecider was not used\n";
@@ -273,7 +235,7 @@ if ($min_wt >= 1.9) {
     print "ESet min weight too high for testcase\n";
     exit(1);
 }
-$eset = $enquire->get_eset(100, $rset, XapianEnquire::USE_EXACT_TERMFREQ, 1.0, NULL, 1.9);
+$eset = $enquire->get_eset(100, $rset, XapianEnquire::USE_EXACT_TERMFREQ, NULL, 1.9);
 $min_wt = 0;
 foreach ($eset->begin() as $i => $dummy) {
     $min_wt = $i->get_weight();
@@ -311,19 +273,6 @@ if ($query->get_description() !== 'Query(VALUE_RANGE 1 19991203 20011204)') {
     exit(1);
 }
 
-# Check DateValueRangeProcessor works.
-function add_vrp_date(&$qp) {
-    $vrpdate = new XapianDateValueRangeProcessor(1, 1, 1960);
-    $qp->add_valuerangeprocessor($vrpdate);
-}
-$qp = new XapianQueryParser();
-add_vrp_date($qp);
-$query = $qp->parse_query('12/03/99..12/04/01');
-if ($query->get_description() !== 'Query(VALUE_RANGE 1 19991203 20011204)') {
-    print "XapianDateValueRangeProcessor didn't work - result was ".$query->get_description()."\n";
-    exit(1);
-}
-
 # Feature test for XapianFieldProcessor
 class testfieldprocessor extends XapianFieldProcessor {
     static $count = 0;
@@ -721,4 +670,50 @@ if ($query->get_description() !== 'Query(b@2)') {
     exit(1);
 }
 
+# Test wrapping of C++ empty() methods as both empty() and is_empty() in PHP.
+$eset = new XapianESet();
+if (!$eset->empty()) {
+    print "Unexpected !\$eset->empty()\n";
+    exit(1);
+}
+if (!$eset->is_empty()) {
+    print "Unexpected !\$eset->is_empty()\n";
+    exit(1);
+}
+$mset = new XapianMSet();
+if (!$mset->empty()) {
+    print "Unexpected !\$mset->empty()\n";
+    exit(1);
+}
+if (!$mset->is_empty()) {
+    print "Unexpected !\$mset->is_empty()\n";
+    exit(1);
+}
+$rset = new XapianRSet();
+if (!$rset->empty()) {
+    print "Unexpected !\$rset->empty()\n";
+    exit(1);
+}
+if (!$rset->is_empty()) {
+    print "Unexpected !\$rset->is_empty()\n";
+    exit(1);
+}
+$coords = new XapianLatLongCoords();
+if (!$coords->empty()) {
+    print "Unexpected !\$coords->empty()\n";
+    exit(1);
+}
+if (!$coords->is_empty()) {
+    print "Unexpected !\$coords->is_empty()\n";
+    exit(1);
+}
+$query = new XapianQuery();
+if (!$query->empty()) {
+    print "Unexpected !\$query->empty()\n";
+    exit(1);
+}
+if (!$query->is_empty()) {
+    print "Unexpected !\$query->is_empty()\n";
+    exit(1);
+}
 ?>
