@@ -510,8 +510,8 @@ def test_newdocument_iter():
         terms.append(termitem.term)
         wdfs.append(termitem.wdf)
         expect_exception(xapian.InvalidOperationError,
-                         "Can't get term frequency from a document termlist "
-                         "which is not associated with a database.",
+                         "get_termfreq() not valid for a TermIterator from a "
+                         "Document which is not associated with a database",
                          getattr, termitem, 'termfreq')
         positers.append([pos for pos in termitem.positer])
 
@@ -845,49 +845,6 @@ def test_spell():
     dbr.close()
     shutil.rmtree(dbpath)
 
-def test_queryparser_custom_vrp():
-    """Test QueryParser with a custom (in python) ValueRangeProcessor.
-
-    """
-    class MyVRP(xapian.ValueRangeProcessor):
-        def __init__(self):
-            xapian.ValueRangeProcessor.__init__(self)
-
-        def __call__(self, begin, end):
-            return (7, "A"+begin, "B"+end)
-
-    queryparser = xapian.QueryParser()
-    myvrp = MyVRP()
-
-    queryparser.add_valuerangeprocessor(myvrp)
-    query = queryparser.parse_query('5..8')
-
-    expect(str(query),
-           'Query(VALUE_RANGE 7 A5 B8)')
-
-def test_queryparser_custom_vrp_deallocation():
-    """Test that QueryParser doesn't delete ValueRangeProcessors too soon.
-
-    """
-    class MyVRP(xapian.ValueRangeProcessor):
-        def __init__(self):
-            xapian.ValueRangeProcessor.__init__(self)
-
-        def __call__(self, begin, end):
-            return (7, "A"+begin, "B"+end)
-
-    def make_parser():
-        queryparser = xapian.QueryParser()
-        myvrp = MyVRP()
-        queryparser.add_valuerangeprocessor(myvrp)
-        return queryparser
-
-    queryparser = make_parser()
-    query = queryparser.parse_query('5..8')
-
-    expect(str(query),
-           'Query(VALUE_RANGE 7 A5 B8)')
-
 def test_queryparser_custom_rp():
     """Test QueryParser with a custom (in python) RangeProcessor.
 
@@ -1549,13 +1506,12 @@ def test_compactor():
         db2.add_document(doc2)
         db2.commit()
 
+        db_to_compact = xapian.Database()
+        db_to_compact.add_database(xapian.Database(db1path))
+        db_to_compact.add_database(xapian.Database(db2path))
         # Compact with the default compactor
         # Metadata conflicts are resolved by picking the first value
-        c = xapian.Compactor()
-        c.add_source(db1path)
-        c.add_source(db2path)
-        c.set_destdir(db3path)
-        c.compact()
+        db_to_compact.compact(db3path)
 
         db3 = xapian.Database(db3path)
         expect([(item.term, item.termfreq) for item in db3.allterms()],
@@ -1582,10 +1538,10 @@ def test_compactor():
                 return b','.join(vals)
 
         c = MyCompactor()
-        c.add_source(db1path)
-        c.add_source(db2path)
-        c.set_destdir(db3path)
-        c.compact()
+        db_to_compact = xapian.Database()
+        db_to_compact.add_database(xapian.Database(db1path))
+        db_to_compact.add_database(xapian.Database(db2path))
+        db_to_compact.compact(db3path, 0, 0, c)
         log = '\n'.join(c.log)
         # Check we got some messages in the log
         expect('Starting postlist' in log, True)
@@ -1727,9 +1683,6 @@ def test_repr():
     expect(repr(xapian.RangeProcessor()) is None, False)
     expect(repr(xapian.DateRangeProcessor(1)) is None, False)
     expect(repr(xapian.NumberRangeProcessor(1)) is None, False)
-    expect(repr(xapian.StringValueRangeProcessor(1)) is None, False)
-    expect(repr(xapian.DateValueRangeProcessor(1)) is None, False)
-    expect(repr(xapian.NumberValueRangeProcessor(1)) is None, False)
     expect(repr(xapian.QueryParser()) is None, False)
     expect(repr(xapian.BoolWeight()) is None, False)
     expect(repr(xapian.TfIdfWeight()) is None, False)
@@ -1744,7 +1697,10 @@ def test_repr():
     expect(repr(xapian.PL2Weight()) is None, False)
     expect(repr(xapian.PL2PlusWeight()) is None, False)
     expect(repr(xapian.DPHWeight()) is None, False)
-    expect(repr(xapian.LMWeight()) is None, False)
+    expect(repr(xapian.LM2StageWeight()) is None, False)
+    expect(repr(xapian.LMAbsDiscountWeight()) is None, False)
+    expect(repr(xapian.LMDirichletWeight()) is None, False)
+    expect(repr(xapian.LMJMWeight()) is None, False)
     expect(repr(xapian.CoordWeight()) is None, False)
     expect(repr(xapian.Compactor()) is None, False)
     expect(repr(xapian.ValuePostingSource(1)) is None, False)
