@@ -6,7 +6,7 @@
 # Originally based on smoketest.php from the PHP4 bindings.
 #
 # Copyright (C) 2006 Networked Knowledge Systems, Inc.
-# Copyright (C) 2008,2009,2010,2011,2016,2019,2025 Olly Betts
+# Copyright (C) 2008,2009,2010,2011,2016,2017,2019,2025 Olly Betts
 # Copyright (C) 2010 Richard Boulton
 #
 # This program is free software; you can redistribute it and/or
@@ -48,7 +48,7 @@ class XapianSmoketest < Test::Unit::TestCase
     @doc.add_posting(@stem.call("there"), 5)
     @doc.add_term("XYzzy")
 
-    @db = Xapian::inmemory_open()
+    @db = Xapian::WritableDatabase.new("", Xapian::DB_BACKEND_INMEMORY)
     @db.add_document(@doc)
 
     @enq = Xapian::Enquire.new(@db)
@@ -108,7 +108,7 @@ class XapianSmoketest < Test::Unit::TestCase
 
   def test_001_database
     assert_not_nil(@db)
-    assert_equal("WritableDatabase()", @db.description())
+    assert_equal("WritableDatabase(InMemory)", @db.description())
     assert_equal(1, @db.doccount())
   end # test_database
 
@@ -430,11 +430,10 @@ class XapianSmoketest < Test::Unit::TestCase
 
         # Compact with the default compactor
         # Metadata conflicts are resolved by picking the first value
-        c = Xapian::Compactor.new()
-        c.add_source(db1path)
-        c.add_source(db2path)
-        c.set_destdir(db3path)
-        c.compact()
+        db_to_compact = Xapian::Database.new()
+        db_to_compact.add_database(Xapian::Database::new(db1path))
+        db_to_compact.add_database(Xapian::Database::new(db2path))
+        db_to_compact.compact(db3path)
 
         db3 = Xapian::Database.new(db3path)
         #assert_equal([(item.term, item.termfreq) for item in db3.allterms()],
